@@ -1,3 +1,4 @@
+import os
 import sys
 
 from django import forms
@@ -41,17 +42,26 @@ class ReCaptchaField(forms.CharField):
             if 'request' in f.f_locals:
                 request = f.f_locals['request']
                 if request:
-                    return request.META['REMOTE_ADDR']
+                    remote_ip = request.META.get('REMOTE_ADDR', '')
+                    forwarded_ip = request.META.get('HTTP_X_FORWARDED_FOR', '')
+                    ip = remote_ip if not forwarded_ip else forwarded_ip
+                    return ip
             f = f.f_back
 
     def clean(self, values):
         super(ReCaptchaField, self).clean(values[1])
         recaptcha_challenge_value = smart_unicode(values[0])
         recaptcha_response_value = smart_unicode(values[1])
+
+        if os.environ.get('RECAPTCHA_TESTING', None) == 'True' and \
+                recaptcha_response_value == 'PASSED':
+            return values[0]
+
         check_captcha = client.submit(recaptcha_challenge_value, \
                 recaptcha_response_value, private_key=self.private_key, \
                 remoteip=self.get_remote_ip(), use_ssl=self.use_ssl)
         if not check_captcha.is_valid:
-            raise forms.util.ValidationError(self.error_messages[\
-                    'captcha_invalid'])
+            raise forms.util.ValidationError(
+                self.error_messages['captcha_invalid']
+            )
         return values[0]
